@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20130228';
+our $VERSION = '0.20130329';
 
-# Table last modified: 2013-02-28
+# Table last modified: 2013-03-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,15 +103,15 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|5[2489]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|2(?:0[1-4]|1[035])|101))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[0168]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|4[158]|2[1245]|3[138]|0[237]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
+    '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[035])|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[245]|1[125689])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|8[2457]|7[02358]|3[0-8]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|1[02-79]|3[0-57-9]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|8[0368]|2[014589]|5[167]|7[27]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457]|1[0-24-69])|5(?:4[035689]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
+    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|8[2457]|7[02358]|3[0-8]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-25-8]|1[14-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|8[0368]|2[014589]|5[167]|7[27]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[015-9]|6[01457]|1[0-24-69])|5(?:4[035689]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|50|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
-    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|3[013489]|2[0-35689]|6[016])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|8[02]|0[1-38]|3[0-4]|5[05]|1[017]|[24][0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|0[357]|8[0134689]|7[0-37-9]|5[0158]|2[0235689]|4[15]|3[013489]|6[016])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|8[02]|0[1-38]|3[0-4]|5[05]|1[017]|[24][0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[0158]|7[135-8]|8[015-8])|7(?:45|8[027]|5[057]|1[2-6]|0[168]|3[36]|2[1-35])|80[78]|408))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
@@ -130,11 +130,11 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:3[029]|1[15])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-4])|080))',
+    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-3])|080))',
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|8[03]|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:[23][0137-9]|4[02-46-8]|0[2-6]|7[0-36]|8[01346-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|6[0-25-8]|5[05-79]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
+    '141' => '(?:8(?:6(?:2[01379]|3[0137-9]|4[02-46-8]|0[2-6]|7[0-36]|8[01346-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|6[0-25-8]|5[05-79]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|5[02578]|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|1[145])|6501))',
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[14]|6[01])))',
@@ -202,7 +202,7 @@ our %ZIP_TABLE = (
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:85(?:[56]6|22|70|1[0-249]|0[12]))',
-    '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:53|78|0[149]|1[1-6]|2[02]|6[08]|8[046])|7(?:11|22|65)|080))',
+    '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:53|78|0[149]|1[1-6]|2[02]|6[08]|8[046])|7(?:11|22|65)|080|173))',
     '221' => '(?:8(?:5(?:[46]0|37|88|1[17]|5[058]|2[023])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:77|3[03]|8[056]|6[1-6]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:8(?:5(?:1[025]|2[0-356]|[58][058]|7[27]|6[067]|4[0-2]|0[125-8]|3[039])|68[67]))',
@@ -218,7 +218,7 @@ our %ZIP_TABLE = (
     '236' => '(?:8(?:5(?:15|0[1-4]|5[05])|6(?:48|53)))',
     '237' => '(?:85(?:23|55|8[58]|1[05]))',
     '238' => '(?:(?:8(?:5(?:8[058]|3[356]|1[013]|2[02]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
-    '239' => '(?:8(?:5(?:01|28|50|8[58])|68[68]))',
+    '239' => '(?:8(?:5(?:01|28|8[58]|5[08])|68[68]))',
     '240' => '(?:(?:8(?:5(?:[02]1|[45]0|15)|612)|019[2-8]))',
     '241' => '(?:8(?:5(?:15|0[12])|606))',
     '242' => '(?:8(?:5(?:[07]7|[58]5)|6(?:01|10)))',
@@ -230,8 +230,8 @@ our %ZIP_TABLE = (
     '248' => '(?:8(?:55[58]|686))',
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|39[28]|[15]92)|85(?:11|55|88)))',
-    '251' => '(?:8(?:5(?:40|2[02]|5[0158]|1[0135]|6[067]|8[18]|3[014]|0[125])|601))',
-    '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|5[258]|1[01]|2[125]|9[2-578])|1(?:[56]2|7[27]|9[1256]|8[1-3589]))|0(?:3(?:7[03-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
+    '251' => '(?:8(?:5(?:40|2[02]|5[0158]|3[0134]|1[0135]|6[067]|8[18]|0[125])|601))',
+    '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|1[01]|2[125]|5[0258]|9[2-578])|1(?:[56]2|7[27]|9[1256]|8[1-3589]))|0(?:3(?:7[03-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:01|10|22|43|67|7[17]|5[058]|8[58]|3[01])|686)|019[25-8]))',
     '254' => '(?:8(?:5(?:43|55|67|8[58]|0[12]|3[023])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
@@ -246,7 +246,7 @@ our %ZIP_TABLE = (
     '264' => '(?:8(?:5(?:[35]0|8[25]|0[15])|6(?:04|46)|733))',
     '265' => '(?:8501)',
     '266' => '(?:8(?:550|733))',
-    '270' => '(?:(?:1(?:3(?:8[1-357]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:9[2578]|8[08])|39[23])|8(?:5(?:[0-2]1|55)|625)|019[28]))',
+    '270' => '(?:(?:1(?:3(?:8[1-357]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:9[2578]|8[08])|39[23])|8(?:5(?:[0-2]1|55)|625)|019[248]))',
     '271' => '(?:8(?:5(?:01|22|33|8[058]|1[0158]|5[0157]|6[02-4])|6(?:66|72|2[05])))',
     '272' => '(?:85(?:[47]3|01|3[38]|[58][058]|2[02]|1[1-368]|6[01]))',
     '273' => '(?:(?:8(?:5(?:7[04]|3[03]|2[0-3]|8[458]|1[0-25]|6[067]|4[023]|5[01568]|0[1-58])|6(?:01|27)|733)|019[2357]))',
@@ -260,7 +260,7 @@ our %ZIP_TABLE = (
     '283' => '(?:(?:8(?:5(?:[01]1|55|88)|650)|0195))',
     '284' => '(?:8555)',
     '285' => '(?:8(?:5(?:50|67|0[1-3]|8[568]|2[0-2]|1[01])|6(?:19|5[05])|765))',
-    '286' => '(?:(?:85(?:[03]1|8[58])|029[23]))',
+    '286' => '(?:(?:85(?:[02]1|8[58])|029[23]))',
     '287' => '(?:(?:8(?:5(?:[58]5|10|0[1-3])|601)|0292))',
     '288' => '(?:8601)',
     '289' => '(?:(?:1(?:59[2-4]|29[78]|69[23]|79[23]|[13]92)|0(?:[124-6]92|39[2-4])|2(?:19[278]|292|595)))',
@@ -432,7 +432,7 @@ our %ZIP_TABLE = (
     '458' => '(?:85(?:30|55|[18][015]|0[1258]|2[0-25]|7[01]))',
     '459' => '(?:85(?:[01]1|22|40))',
     '460' => '(?:8(?:6(?:90|7[0-2489]|8[1-9]|6[035-9]|0[1-3689]|3[0-35-8]|5[0135-7]|2[013568]|1[013-9])|4(?:7[02357]|0[1-35-8]|1[125-7]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-69]|6[0-28]|4[014578])|5(?:5[01589]|[23][0-58]|8[05-8]|1[0-68]|4[0135]|7[04578]|0[13-9]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|65|91|0[1-46-8]|1[18])|20[1-4]))',
-    '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[125])|6(?:66|80|4[015]|0[2358]|5[01458]|3[0169]|2[016]|1[024]|7[0-3568])|7(?:0[36-8]|2[159]|9[58]|1[0457])))',
+    '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[1256])|6(?:66|80|4[015]|0[2358]|5[01458]|3[0169]|2[016]|1[024]|7[0-3568])|7(?:0[36-8]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|4[03]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08])|666))',
     '463' => '(?:85(?:[18]0|5[057]|2[128]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
     '464' => '(?:8(?:5(?:85|5[058]|4[035-7]|1[12]|6[0167]|2[0-2]|3[01369]|7[017])|6(?:[278]1|0[1-3]|4[134]|3[1-357]|5[0-4]|6[12]|1[0135-7])|710))',
@@ -500,7 +500,7 @@ our %ZIP_TABLE = (
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
     '530' => '(?:8(?:2(?:8[0-278]|3[0249]|5[0-256]|6[0236]|4[0157]|2[126-8]|1[0-8]|7[08]|0[1-79])|5(?:44|2[1-3]|6[05-7]|0[14]|5[01568]|7[4578]|3[15]|1[1-37]|8[023568])|3(?:3[348]|0[148]|1[018]|8[389]|4[16]|2[1-47]|5[035])|4(?:75|80|1[015]|0[1-38]|4[18])|6(?:1[018]|0[12]|8[08])|79[136-8]))',
-    '531' => '(?:8(?:5(?:26|67|88|0[1-3]|5[58]|1[01])|787))',
+    '531' => '(?:(?:8(?:5(?:26|67|88|0[1-3]|5[58]|1[01])|787)|6053))',
     '532' => '(?:8(?:5(?:35|60|77|2[045]|8[58]|0[1578]|5[0258]|1[145])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
     '534' => '(?:85(?:11|85|0[12]))',
@@ -509,7 +509,7 @@ our %ZIP_TABLE = (
     '537' => '(?:8(?:5[01]1|686))',
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
-    '540' => '(?:(?:8(?:5(?:66|4[0147]|2[1267]|5[01589]|0[158]|3[03-5]|7[01578]|1[0-2579]|8[14-8])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
+    '540' => '(?:(?:8(?:5(?:66|4[0147]|2[1267]|5[01589]|3[03-5]|0[1578]|7[01578]|1[0-2579]|8[14-8])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
     '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|7[1568]|4[0-35-7]|8[1579]|0[1-35689]|1[16-8]|6[368]|3[014578])|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|[58][58]|0[12])|6(?:01|66|8[68])))',
@@ -540,8 +540,8 @@ our %ZIP_TABLE = (
     '570' => '(?:8(?:5(?:39|40|0[125-7]|[58][58]|1[15])|6(?:[68]6|34|77)))',
     '571' => '(?:8(?:5(?:[45]5|67|71|8[05]|0[2-47])|6(?:33|86)))',
     '572' => '(?:85(?:40|67|8[01589]|2[28]|3[013]|7[02]|5[0158]|0[1578]|1[01]))',
-    '573' => '(?:(?:8(?:5(?:11|34|73)|666)|10(?:[34]0|01)|019[25]))',
-    '574' => '(?:85(?:01|55|3[04]))',
+    '573' => '(?:(?:8(?:5(?:11|34|73)|666)|10(?:[134]0|01)|019[25]))',
+    '574' => '(?:85(?:[58]5|01|3[04]))',
     '575' => '(?:85(?:[01]1|30|[58][58]))',
     '576' => '(?:8501)',
     '577' => '(?:8(?:5(?:11|40|3[37]|0[2359]|5[01458]|8[1258]|6[067]|7[57]|2[0-2])|611))',
@@ -612,7 +612,7 @@ our %ZIP_TABLE = (
     '648' => '(?:(?:0(?:2(?:8\d|9[2-8])|198|392)|85(?:41|85)))',
     '649' => '(?:(?:6(?:49[2-4]|59[235]|[126]92)|(?:[04]1|35)92|219[2358]|719[245]))',
     '650' => '(?:8(?:5(?:43|1[015]|5[01589]|2[0-258]|6[057]|3[0369]|7[015-7]|8[04-689]|0[1-35])|6(?:[68][06]|7[07])|7(?:87|94)))',
-    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[078]|9[4-7])|49[24])|01(?:9[35]|8[1578]|7[01578])|1195))',
+    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[078]|9[4-7])|49[24])|01(?:7[0-2578]|9[35]|8[1578])|1195))',
     '652' => '(?:85(?:[17]0|01|85|5[05]))',
     '653' => '(?:85(?:70|85))',
     '654' => '(?:(?:85(?:70|85)|019[2358]))',
@@ -860,7 +860,7 @@ our %ZIP_TABLE = (
     '901' => '(?:(?:2(?:5(?:40|88|97|6[0679]|0[1268]|1[0-25]|5[0-35-9]|3[014]|2[0156])|6(?:86|0[127]|1[01])|7(?:01|10|33)|49[2356]|39[25])|0(?:49[2-6]|29[2-5]|19[2-4]|39[23]|592|695)|3(?:[679]92|19[23]|59[25]|496|895)|1(?:19[2356]|39[23]|[24]92|595)))',
     '902' => '(?:85(?:21|8[58]|5[05]|1[0-2]|7[01]))',
     '903' => '(?:(?:02(?:20|1[013-578]|0[13-7])|860[1-3]))',
-    '904' => '(?:(?:0(?:49[2-6]|19[2-5]|39[2-5]|29[35])|2(?:19[2-6]|39[2-4]|29[23])|1(?:29[2-4]|[13]92)|85(?:[01]1|85)))',
+    '904' => '(?:(?:0(?:49[2-6]|19[2-5]|39[2-5]|29[35])|2(?:19[2-6]|39[2-4]|29[23])|8(?:5(?:[01]1|85)|686)|1(?:29[2-4]|[13]92)))',
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|[24]92|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
     '906' => '(?:(?:0[256]92|8[56]01))',
     '907' => '(?:(?:850[1-3]|1[28]92))',
